@@ -18,6 +18,7 @@ import os
 import subprocess
 
 from oslo_log import log as logging
+import six
 
 from muranoagent import bunch
 import muranoagent.exceptions
@@ -73,7 +74,8 @@ class ChefPuppetExecutorBase(object):
         retcode = process.poll()
 
         if stdout is not None:
-            stdout = stdout.decode('utf-8')
+            if not isinstance(stdout, six.text_type):
+                stdout = stdout.decode('utf-8')
             LOG.debug(u"'{0}' execution stdout: "
                       u"'{1}'".format(self.module_name, stdout))
         if stderr is not None:
